@@ -13,12 +13,12 @@ client.connect(null);
 message = "GET / HTTP/1.1\r\nHost: www.google.com\r\n\r\n";
 
 os = client.get_output_stream();
-ds = Gio.DataOutputStream._new(os);
+ds = new Gio.DataOutputStream.c_new(os);
 ds.put_string(message);
 
 os.flush();
 
-input = Gio.DataInputStream._new(client.get_input_stream());
+input = new Gio.DataInputStream.c_new(client.get_input_stream());
 
 out = input.read_until("", 0);
-Seed.print(out);
\ No newline at end of file
+Seed.print(out);
