@@ -1,13 +1,13 @@
 #!/usr/bin/env seed
-Seed.import_namespace("Gtk");
-Seed.import_namespace("Gio");
-Seed.import_namespace("Notify");
+Gtk = imports.gi.Gtk;
+Gio = imports.gi.Gio;
+Notify = imports.gi.Notify;
 
 Gtk.init(null, null);
 
 function file_changed(monitor, child, other, event)
 {
-    var notification = 
+    var notification =
 	new Notify.Notification({summary: "File Notification",
                              body : "It's not clear what notification system this file is providing an example of." });
     notification.set_timeout(5000);
